@@ -264,4 +264,103 @@ class Cases:
 		:returns:
 			New string.
 		'''
-		return separator.join(s for s in cls.SPLIT_RE.split(string) if s)
\ No newline at end of file
+		return separator.join(s for s in cls.SPLIT_RE.split(string) if s)
+
+class Morse:
+	'''Convert text to morse, and vice versa.'''
+	NUMBERS = {
+		"1": ".----",
+		"2": "..---",
+		"3": "...--",
+		"4": "....-",
+		"5": ".....",
+		"6": "-....",
+		"7": "--...",
+		"8": "---..",
+		"9": "----.",
+		"0": "-----",
+	}
+	LETTERS = {
+		"A": ".-",
+		"B": "-...",
+		"C": "-.-.",
+		"D": "-..",
+		"E": ".",
+		"F": "..-.",
+		"G": "--.",
+		"H": "....",
+		"I": "..",
+		"J": ".---",
+		"K": "-.-",
+		"L": ".-..",
+		"M": "--",
+		"N": "-.",
+		"O": "---",
+		"P": ".--.",
+		"Q": "--.-",
+		"R": ".-.",
+		"S": "...",
+		"T": "-",
+		"U": "..-",
+		"V": "...-",
+		"W": ".--",
+		"X": "-..-",
+		"Y": "-.--",
+		"Z": "--..",
+
+		"Á": ".--.-",
+		"Ä": ".-.-",
+		"É": "..-..",
+		"Ñ": "--.--",
+		"Ö": "---.",
+		"Ü": "..--"
+	}
+
+	PUNCTUATION = {
+		",": "--..--",
+		".": ".-.-.-",
+		"?": "..--..",
+		"/": "-..-.",
+		"-": "-....-",
+		"(": "-.--.",
+		")": "-.--.-",
+		" ": "/",
+		"@": ".--.-.",
+		"+": ".-.-.",
+		"=": "-...-",
+		"'": '.----.',
+		'"': '.-..-.',
+		":": "---...",
+		";": "-.-.-.",
+		"!": "-.-.--",
+		"&": ".-...",
+		}
+
+
+	CODE = {**LETTERS, **NUMBERS, **PUNCTUATION}
+
+	CODE_REVERSED = {value:key for key,value in CODE.items()}
+
+	@classmethod
+	def decode(cls, morse_code: str) -> str:
+		decoded = ""
+
+		for char in morse_code.split():
+			decoded_char = cls.CODE_REVERSED.get(char)
+			if decoded_char is None:
+				raise ValueError(f"Error in input. Cannot decode code: {repr(char)}")
+			decoded += decoded_char
+
+		return decoded
+
+	@classmethod
+	def encode(cls, sentence: str) -> str:
+		encoded = list()
+
+		for char in sentence.upper():
+			encoded_char = cls.CODE.get(char)
+			if encoded_char is None:
+				raise ValueError(f"Error in input. Cannot encode symbol: {repr(char)}")
+			encoded.append(cls.CODE.get(char))
+
+		return " ".join(encoded)
\ No newline at end of file
