@@ -60,7 +60,7 @@ class Validator():
 		return cls.is_re_pattern_in_text(r"(^[a-zA-Z0-9_.+-]+@[a-zA-Z0-9-]+\.[a-zA-Z0-9-.]+$)", email)
 
 	@staticmethod
-	def validate_url(url):
+	def validate_url(url: str):
 		'''Validate url address.
 		- Validator.validate_url("https://example.com/") -> True
 		- Validator.validate_url("example.com") -> False
@@ -68,7 +68,7 @@ class Validator():
 		try:
 			result = urlparse(url)
 			return all([result.scheme, result.netloc])
-		except:
+		except TypeError:
 			return False
 
 	@staticmethod
